<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../forms/aboutdialog.ui" line="14"/>
        <source>About Qmmp</source>
        <translation>QMMP について</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="40"/>
        <source>About</source>
        <translation>QMMP について</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="54"/>
        <source>Authors</source>
        <translation>作者</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="68"/>
        <source>Translators</source>
        <translation>翻訳者</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="82"/>
        <source>Thanks To</source>
        <translation>協力者</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="96"/>
        <source>License Agreement</source>
        <translation>使用許諾契約</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="61"/>
        <source>:/txt/authors_en.txt</source>
        <translation>:/txt/authors_ja.txt</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="62"/>
        <source>:/txt/thanks_en.txt</source>
        <translation>:/txt/thanks_ja.txt</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="63"/>
        <source>:/txt/translators_en.txt</source>
        <translation>:/txt/translators_ja.txt</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="81"/>
        <source>Qt-based Multimedia Player (Qmmp)</source>
        <translation>Qt 製マルティミディアプレイヤー QMMP</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="82"/>
        <source>Version:</source>
        <translation>バージョン:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="83"/>
        <source>:txt/description_en.txt</source>
        <translation>:txt/description_ja.txt</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="84"/>
        <source>Input plugins:</source>
        <translation>入力側プラグイン:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="93"/>
        <source>Output plugins:</source>
        <translation>出力側プラグイン:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="102"/>
        <source>Visual plugins:</source>
        <translation>視覚効果プラグイン:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="111"/>
        <source>Effect plugins:</source>
        <translation>音響効果プラグイン:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="120"/>
        <source>General plugins:</source>
        <translation>一般プラグイン:</translation>
    </message>
</context>
<context>
    <name>ActionManager</name>
    <message>
        <location filename="../actionmanager.cpp" line="37"/>
        <source>&amp;Play</source>
        <translation>再生(&amp;Y)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="37"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="38"/>
        <source>&amp;Pause</source>
        <translation>一時停止(&amp;P)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="38"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="39"/>
        <source>&amp;Stop</source>
        <translation>終止(&amp;S)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="39"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="40"/>
        <source>&amp;Previous</source>
        <translation>前の曲(&amp;R)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="40"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="41"/>
        <source>&amp;Next</source>
        <translation>次の曲(&amp;N)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="41"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="42"/>
        <source>&amp;Play/Pause</source>
        <translation>再生/一時停止(&amp;A)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="42"/>
        <source>Space</source>
        <translation>Space</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="43"/>
        <source>&amp;Jump to File</source>
        <translation>ファイルを指定して即刻再生(&amp;J)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="43"/>
        <source>J</source>
        <translation>J</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="44"/>
        <source>&amp;Repeat Playlist</source>
        <translation>プレイリストを繰り返す(&amp;L)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="44"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="45"/>
        <source>&amp;Repeat Track</source>
        <translation>トラックを繰り返す(&amp;T)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="45"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="46"/>
        <source>&amp;Shuffle</source>
        <translation>シャッフル(&amp;F)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="46"/>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="47"/>
        <source>&amp;No Playlist Advance</source>
        <translation>次の曲に進まず終止(&amp;N)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="48"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="49"/>
        <source>&amp;Stop After Selected</source>
        <translation>選んだ曲を再生後に終止(&amp;S)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="50"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="51"/>
        <source>&amp;Clear Queue</source>
        <translation>キューを消去(&amp;C)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="51"/>
        <source>Alt+Q</source>
        <translation>Alt+Q</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="53"/>
        <source>Show Playlist</source>
        <translation>プレイリストを表示</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="53"/>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="54"/>
        <source>Show Equalizer</source>
        <translation>イコライザ一時を表示</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="54"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="55"/>
        <source>Always on Top</source>
        <translation>常に前面へ</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="56"/>
        <source>Put on All Workspaces</source>
        <translation>常に表示中のワークスペースに置く</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="57"/>
        <source>Double Size</source>
        <translation>倍サイズ</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="57"/>
        <source>Meta+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="59"/>
        <source>&amp;Add File</source>
        <translation>ファイルを追加(&amp;F)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="59"/>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="60"/>
        <source>&amp;Add Directory</source>
        <translation>ディレクトリを追加(&amp;D)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="60"/>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="61"/>
        <source>&amp;Add Url</source>
        <translation>URL を追加(&amp;U)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="61"/>
        <source>U</source>
        <translation>U</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="62"/>
        <source>&amp;Remove Selected</source>
        <translation>選択したものを除去(&amp;V)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="63"/>
        <source>Del</source>
        <translation>Delele</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="64"/>
        <source>&amp;Remove All</source>
        <translation>すべて除去(&amp;M)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="65"/>
        <source>&amp;Remove Unselected</source>
        <translation>選択外のものを除去(&amp;N)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="67"/>
        <source>Remove unavailable files</source>
        <translation>無効なファイルを除去</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="69"/>
        <source>Remove duplicates</source>
        <translation>重複分を除去</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="70"/>
        <source>&amp;Queue Toggle</source>
        <translation>選んだプレイリストを キューに追加/キューから撤去</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="70"/>
        <source>Q</source>
        <translation>Q</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="71"/>
        <source>Invert Selection</source>
        <translation>選択範囲を反転</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="72"/>
        <source>&amp;Select None</source>
        <translation>選択を解除(&amp;N)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="73"/>
        <source>&amp;Select All</source>
        <translation>すべて選択(&amp;E)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="74"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="75"/>
        <source>&amp;View Track Details</source>
        <translation>トラックの詳細を表示(&amp;D)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="75"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="77"/>
        <source>&amp;New List</source>
        <translation>新規リスト(&amp;W)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="77"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="78"/>
        <source>&amp;Delete List</source>
        <translation>リストを削除(&amp;D)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="78"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="79"/>
        <source>&amp;Load List</source>
        <translation>リストを読込(&amp;L)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="79"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="80"/>
        <source>&amp;Save List</source>
        <translation>リストを保存(&amp;S)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="80"/>
        <source>Shift+S</source>
        <translation>Shift+S</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="81"/>
        <source>&amp;Select Next Playlist</source>
        <translation>次のプレイリストを選択(&amp;N)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="82"/>
        <source>Ctrl+PgDown</source>
        <translation>Ctrl+PgDown</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="83"/>
        <source>&amp;Select Previous Playlist</source>
        <translation>前のプレイリストを選択(&amp;P)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="84"/>
        <source>Ctrl+PgUp</source>
        <translation>Ctrl+PgUp</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="85"/>
        <source>&amp;Show Playlists</source>
        <translation>プレイリストを表示(&amp;H)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="86"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="88"/>
        <source>&amp;Settings</source>
        <translation>設定(&amp;S)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="88"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="89"/>
        <source>&amp;About</source>
        <translation>QMMP について(&amp;A)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="90"/>
        <source>&amp;About Qt</source>
        <translation>Qt について(&amp;Q)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="91"/>
        <source>&amp;Exit</source>
        <translation>終了(&amp;X)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="91"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
</context>
<context>
    <name>AddUrlDialog</name>
    <message>
        <location filename="../forms/addurldialog.ui" line="13"/>
        <source>Enter URL to add</source>
        <translation>追加したい URL を記入</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="51"/>
        <source>&amp;Add</source>
        <translation>追加(&amp;A)</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="58"/>
        <source>&amp;Cancel</source>
        <translation>キャンセル(&amp;C)</translation>
    </message>
    <message>
        <location filename="../addurldialog.cpp" line="117"/>
        <source>Error</source>
        <translation>事故</translation>
    </message>
</context>
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="54"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>プレイリストをクリアしない</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="55"/>
        <source>Start playing current song</source>
        <translation>今の曲から再生を開始</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="56"/>
        <source>Pause current song</source>
        <translation>今の曲で一時停止</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="57"/>
        <source>Pause if playing, play otherwise</source>
        <translation>再生中なら一時停止、一時停止しておれば再生</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="58"/>
        <source>Stop current song</source>
        <translation>今の曲で終止</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="59"/>
        <source>Display Jump to File dialog</source>
        <translation>「ファイルを指定して即刻再生」ダイアログを表示</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="60"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>音量設定 (例: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="61"/>
        <source>Skip forward in playlist</source>
        <translation>プレイリストでの次の曲にスキップ</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="62"/>
        <source>Skip backwards in playlist</source>
        <translation>プレイリストで前の曲にスキップ</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="63"/>
        <source>Show/hide application</source>
        <translation>アプリケーションウィンドウを表示/非表示</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="64"/>
        <source>Display Add File dialog</source>
        <translation>「ファイル追加」ダイアログを表示</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="65"/>
        <source>Display Add Directory dialog</source>
        <translation>「ディレクトリ追加」ダイアログを表示</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../forms/configdialog.ui" line="14"/>
        <source>Qmmp Settings</source>
        <translation>QMMP 設定</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="98"/>
        <source>Appearance</source>
        <translation>外観</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="107"/>
        <location filename="../forms/configdialog.ui" line="463"/>
        <location filename="../configdialog.cpp" line="366"/>
        <source>Playlist</source>
        <translation>プレイリスト</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="116"/>
        <source>Plugins</source>
        <translation>プラグイン</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="125"/>
        <source>Advanced</source>
        <translation>上級</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="134"/>
        <source>Connectivity</source>
        <translation>接続</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="143"/>
        <location filename="../forms/configdialog.ui" line="1131"/>
        <source>Audio</source>
        <translation>音響</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="152"/>
        <source>Shortcuts</source>
        <translation>ショートカット</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="184"/>
        <source>Skins</source>
        <translation>スキン</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="215"/>
        <source>Add...</source>
        <translation>追加...</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="228"/>
        <source>Refresh</source>
        <translation>更新</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="249"/>
        <source>Miscellaneous</source>
        <translation>各種設定</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="255"/>
        <location filename="../configdialog.cpp" line="360"/>
        <source>View</source>
        <translation>観容</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="261"/>
        <source>Hide on close</source>
        <translation>「閉じる」で隠す</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="268"/>
        <source>Start hidden</source>
        <translation>開始時に隠す</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="275"/>
        <source>Use skin cursors</source>
        <translation>スキンカーソルを使用</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="291"/>
        <source>Fonts</source>
        <translation>書体</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="309"/>
        <source>Player:</source>
        <translation>プレイヤー:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="331"/>
        <location filename="../forms/configdialog.ui" line="379"/>
        <source>???</source>
        <translation>???</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="338"/>
        <location filename="../forms/configdialog.ui" line="386"/>
        <location filename="../forms/configdialog.ui" line="552"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="357"/>
        <source>Playlist:</source>
        <translation>プレイリスト:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="393"/>
        <source>Use bitmap font if available</source>
        <translation>あればビットマップフォントを使用</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="403"/>
        <source>Transparency</source>
        <translation>透過効果</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="409"/>
        <source>Main window</source>
        <translation>メインウィンドウ</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="432"/>
        <location filename="../forms/configdialog.ui" line="456"/>
        <location filename="../forms/configdialog.ui" line="480"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="439"/>
        <source>Equalizer</source>
        <translation>イコライザー</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="511"/>
        <source>Metadata</source>
        <translation>メタデータ</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="523"/>
        <source>Load metadata from files</source>
        <translation>ファイルからメタデータを読み込む</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="533"/>
        <source>Song Display</source>
        <translation>演目表示</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="539"/>
        <source>Title format:</source>
        <translation>タイトルの表示形式:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="559"/>
        <source>Convert underscores to blanks</source>
        <translation>下線記号 _ を空白文字で表示</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="566"/>
        <source>Convert %20 to blanks</source>
        <translation>%20 を空白文字で表示</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="573"/>
        <source>Show protocol</source>
        <translation>プロトコルを表示</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="580"/>
        <source>Show song numbers</source>
        <translation>曲番号つきで表示</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="587"/>
        <source>Show playlists</source>
        <translation>プレイリストを表示</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="596"/>
        <source>Show popup information</source>
        <translation>情報吹き出しを表示</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="606"/>
        <source>Edit template</source>
        <translation>ひな型を編集</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="628"/>
        <source>Show anchor</source>
        <translation>アンカーを表示</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="638"/>
        <source>Align song numbers</source>
        <translation>曲番号のみを表示</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="686"/>
        <location filename="../forms/configdialog.ui" line="1153"/>
        <source>Preferences</source>
        <translation>プラグイン調整</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="699"/>
        <location filename="../forms/configdialog.ui" line="761"/>
        <location filename="../forms/configdialog.ui" line="1166"/>
        <source>Information</source>
        <translation>情報</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="735"/>
        <source>Description</source>
        <translation>プラグイン分類</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="740"/>
        <source>Filename</source>
        <translation>ファイル名</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="752"/>
        <source>File Dialog</source>
        <translation>ファイルダイアログ</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="784"/>
        <source>Cover Image Retrieve</source>
        <translation>アルバム表紙画像の取得</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="790"/>
        <source>Use separate image files</source>
        <translation>分割された画像ファイルを利用</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="800"/>
        <source>Include files:</source>
        <translation>対象ファイル形式:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="810"/>
        <source>Exclude files:</source>
        <translation>除外ファイル形式:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="822"/>
        <source>Recursive search depth:</source>
        <translation>再帰検索の深度:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="867"/>
        <location filename="../configdialog.cpp" line="354"/>
        <source>Playback</source>
        <translation>再生</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="873"/>
        <source>Continue playback on startup</source>
        <translation>前回終了時の曲から継続して再生</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="899"/>
        <source>Proxy</source>
        <translation>代理</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="911"/>
        <source>Enable proxy usage</source>
        <translation>代理を利用する</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="918"/>
        <source>Proxy host name:</source>
        <translation>代理ホスト名:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="931"/>
        <source>Proxy port:</source>
        <translation>代理ポート:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="944"/>
        <source>Use authentication with proxy</source>
        <translation>代理経由の認証を利用</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="951"/>
        <source>Proxy user name:</source>
        <translation>代理者ユーザー名:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="964"/>
        <source>Proxy password:</source>
        <translation>代理者パスワード:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1001"/>
        <source>Replay Gain</source>
        <translation>リプレイゲイン</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1007"/>
        <source>Replay Gain mode:</source>
        <translation>リプレイゲインモード:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1024"/>
        <source>Preamp:</source>
        <translation>プリアンプ:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1056"/>
        <location filename="../forms/configdialog.ui" line="1101"/>
        <source>dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1069"/>
        <source>Default gain:</source>
        <translation>デフォルトゲイン:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1121"/>
        <source>Use  peak info to prevent clipping</source>
        <translation>クリッピング現象を抑えるためピーク情報を使う</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1137"/>
        <source>Output:</source>
        <translation>出力:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1189"/>
        <source>Buffer size:</source>
        <translation>バッファーサイズ:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1202"/>
        <source>ms</source>
        <translation>ミリ秒</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1231"/>
        <source>Use software volume control</source>
        <translation>ソフトウェアによる音量制御を利用</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1238"/>
        <source>16-bit output</source>
        <translation>16ビット出力</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1272"/>
        <source>Action</source>
        <translation>動作</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1277"/>
        <source>Shortcut</source>
        <translation>ショートカット</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1285"/>
        <source>Change shortcut...</source>
        <translation>変更</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="74"/>
        <source>Track</source>
        <translation>トラック</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="75"/>
        <location filename="../configdialog.cpp" line="430"/>
        <source>Album</source>
        <translation>アルバム</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="76"/>
        <source>Disabled</source>
        <translation>無効</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="209"/>
        <source>Archived skin</source>
        <translation>書庫化スキン</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="231"/>
        <source>Unarchived skin</source>
        <translation>非書庫化スキン</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="244"/>
        <source>Transports</source>
        <translation>転送</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="255"/>
        <source>Decoders</source>
        <translation>デコーダー</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="265"/>
        <source>Engines</source>
        <translation>エンジン</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="275"/>
        <source>Effects</source>
        <translation>音響効果</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="285"/>
        <source>Visualization</source>
        <translation>視覚効果</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="295"/>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="372"/>
        <source>Misc</source>
        <translation>いろいろ</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="429"/>
        <source>Artist</source>
        <translation>アーティスト</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="431"/>
        <source>Title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="432"/>
        <source>Track number</source>
        <translation>トラック番号</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="433"/>
        <source>Two-digit track number</source>
        <translation>トラック番号 数字2桁</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="434"/>
        <source>Genre</source>
        <translation>ジャンル</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="435"/>
        <source>Comment</source>
        <translation>コメント</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="436"/>
        <source>Composer</source>
        <translation>作曲者</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="437"/>
        <source>Disc number</source>
        <translation>ディスク番号</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="438"/>
        <source>File name</source>
        <translation>ファイル名</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="439"/>
        <source>File path</source>
        <translation>ファイルパス</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="440"/>
        <source>Year</source>
        <translation>年</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="441"/>
        <source>Condition</source>
        <translation>定番</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="524"/>
        <source>Select Skin Files</source>
        <translation>スキンファイルを選択</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="525"/>
        <source>Skin files</source>
        <translation>スキンファイル</translation>
    </message>
</context>
<context>
    <name>EqWidget</name>
    <message>
        <location filename="../eqwidget.cpp" line="43"/>
        <source>Equalizer</source>
        <translation>イコライザー</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="154"/>
        <location filename="../eqwidget.cpp" line="177"/>
        <source>preset</source>
        <translation>プリセット</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="261"/>
        <source>&amp;Load/Delete</source>
        <translation>読み込み/削除(&amp;L)</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="263"/>
        <source>&amp;Save Preset</source>
        <translation>プリセットを保存(&amp;S)</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="265"/>
        <source>&amp;Save Auto-load Preset</source>
        <translation>自動読み込みされたプリセットを保存(&amp;S)</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="267"/>
        <source>&amp;Import</source>
        <translation>移入(&amp;I)</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="270"/>
        <source>&amp;Clear</source>
        <translation>消去(&amp;C)</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="299"/>
        <source>Saving Preset</source>
        <translation>プリセットを保存しています</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="300"/>
        <source>Preset name:</source>
        <translation>プリセット名:</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="301"/>
        <source>preset #</source>
        <translation>プリセット番号</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="392"/>
        <source>Import Preset</source>
        <translation>プリセットを移入</translation>
    </message>
</context>
<context>
    <name>JumpToTrackDialog</name>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="14"/>
        <source>Jump To Track</source>
        <translation>トラックを指定して即刻再生</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="37"/>
        <source>Filter</source>
        <translation>フィルター</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="70"/>
        <location filename="../jumptotrackdialog.cpp" line="86"/>
        <location filename="../jumptotrackdialog.cpp" line="137"/>
        <source>Queue</source>
        <translation>キューに入れる</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="83"/>
        <source>Refresh</source>
        <translation>再実行</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="96"/>
        <source>Jump To</source>
        <translation>この曲に跳ぶ</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="53"/>
        <source>Q</source>
        <translation>Q</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="54"/>
        <source>J</source>
        <translation>J</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="55"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="84"/>
        <location filename="../jumptotrackdialog.cpp" line="135"/>
        <source>Unqueue</source>
        <translation>キューから除く</translation>
    </message>
</context>
<context>
    <name>MainDisplay</name>
    <message>
        <location filename="../display.cpp" line="57"/>
        <source>Previous</source>
        <translation>前の曲</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="61"/>
        <source>Play</source>
        <translation>再生</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="64"/>
        <source>Pause</source>
        <translation>一時停止</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="67"/>
        <source>Stop</source>
        <translation>終止</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="70"/>
        <source>Next</source>
        <translation>次の曲</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="73"/>
        <source>Add file</source>
        <translation>ファイルを追加</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="80"/>
        <source>Equalizer</source>
        <translation>イコライザー</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="83"/>
        <source>Playlist</source>
        <translation>プレイリスト</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="88"/>
        <source>Repeat playlist</source>
        <translation>プレイリストを繰り返し</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="91"/>
        <source>Shuffle</source>
        <translation>シャッフル</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="101"/>
        <source>Volume</source>
        <translation>音量</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="107"/>
        <source>Balance</source>
        <translation>バランス</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="296"/>
        <source>Volume: %1%</source>
        <translation>音量: %1%</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="300"/>
        <source>Balance: %1% right</source>
        <translation>バランス: %1% 右へ</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="302"/>
        <source>Balance: %1% left</source>
        <translation>バランス: %1% 左へ</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="304"/>
        <source>Balance: center</source>
        <translation>バランス: 中央に</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="315"/>
        <source>Seek to: %1</source>
        <translation>%1 に移動</translation>
    </message>
</context>
<context>
    <name>MainVisual</name>
    <message>
        <location filename="../mainvisual.cpp" line="280"/>
        <source>Visualization Mode</source>
        <translation>視覚効果モード</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="283"/>
        <source>Analyzer</source>
        <translation>スペクトルアナライザー</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="284"/>
        <source>Scope</source>
        <translation>オシロスコープ</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="285"/>
        <source>Off</source>
        <translation>使わない</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="292"/>
        <source>Analyzer Mode</source>
        <translation>アナライザーモード</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="295"/>
        <source>Normal</source>
        <translation>通常</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="296"/>
        <source>Fire</source>
        <translation>炎</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="297"/>
        <source>Vertical Lines</source>
        <translatorcomment>Winamp の表記どおり</translatorcomment>
        <translation>線</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="298"/>
        <source>Lines</source>
        <translation>線</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="299"/>
        <source>Bars</source>
        <translation>点</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="312"/>
        <source>Peaks</source>
        <translation>ピーク表示</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="316"/>
        <source>Refresh Rate</source>
        <translation>再描画の頻度</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="319"/>
        <source>50 fps</source>
        <translation>50 フレーム毎秒</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="320"/>
        <source>25 fps</source>
        <translation>25 フレーム毎秒</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="321"/>
        <source>10 fps</source>
        <translation>10 フレーム毎秒</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="322"/>
        <source>5 fps</source>
        <translation>5 フレーム毎秒</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="329"/>
        <source>Analyzer Falloff</source>
        <translation>アナライザー減衰速度</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="332"/>
        <location filename="../mainvisual.cpp" line="346"/>
        <source>Slowest</source>
        <translation>さらに遅く</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="333"/>
        <location filename="../mainvisual.cpp" line="347"/>
        <source>Slow</source>
        <translation>遅く</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="334"/>
        <location filename="../mainvisual.cpp" line="348"/>
        <source>Medium</source>
        <translation>適度</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="335"/>
        <location filename="../mainvisual.cpp" line="349"/>
        <source>Fast</source>
        <translation>速く</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="336"/>
        <location filename="../mainvisual.cpp" line="350"/>
        <source>Fastest</source>
        <translation>さらに速く</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="343"/>
        <source>Peaks Falloff</source>
        <translation>ピーク減衰速度</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="356"/>
        <source>Background</source>
        <translation>背景</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="357"/>
        <source>Transparent</source>
        <translation>透過させる</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="245"/>
        <source>Choose a directory</source>
        <translation>ディレクトリを選択</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>All Supported Bitstreams</source>
        <translation>サポート対象のすべてのデジタル録音物</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Select one or more files to open</source>
        <translation>開きたいファイルを選ぶ (複数可)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="440"/>
        <source>Playlist</source>
        <translation>プレイリスト</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>View</source>
        <translation>観容</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="460"/>
        <source>Tools</source>
        <translation>ツール</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="510"/>
        <location filename="../mainwindow.cpp" line="536"/>
        <source>Playlist Files</source>
        <translation>プレイリストファイル</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="512"/>
        <source>Open Playlist</source>
        <translation>プレイリストを開く</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="537"/>
        <source>Save Playlist</source>
        <translation>プレイリストを保存</translation>
    </message>
</context>
<context>
    <name>PlayList</name>
    <message>
        <location filename="../playlist.cpp" line="53"/>
        <source>Playlist</source>
        <translation>プレイリスト</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="177"/>
        <source>&amp;Copy Selection To</source>
        <translation>選んだ曲目で新しいプレイリストを作る(&amp;C)</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="204"/>
        <source>Sort List</source>
        <translation>リストを並び換え</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="207"/>
        <location filename="../playlist.cpp" line="242"/>
        <source>By Title</source>
        <translation>タイトル順に</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="211"/>
        <location filename="../playlist.cpp" line="246"/>
        <source>By Album</source>
        <translation>アルバム名順に</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="215"/>
        <location filename="../playlist.cpp" line="250"/>
        <source>By Artist</source>
        <translation>アーティスト名順に</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="219"/>
        <location filename="../playlist.cpp" line="254"/>
        <source>By Filename</source>
        <translation>ファイル名順に</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="223"/>
        <location filename="../playlist.cpp" line="258"/>
        <source>By Path + Filename</source>
        <translation>パスとファイル名の順に</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="227"/>
        <location filename="../playlist.cpp" line="262"/>
        <source>By Date</source>
        <translation>日付順に</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="231"/>
        <location filename="../playlist.cpp" line="266"/>
        <source>By Track Number</source>
        <translation>トラック番号順に</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="239"/>
        <source>Sort Selection</source>
        <translation>選択範囲内で並び換え</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="274"/>
        <source>Randomize List</source>
        <translation>リストを順不同に</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="276"/>
        <source>Reverse List</source>
        <translation>リストを逆順に</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="283"/>
        <source>Actions</source>
        <translation>動作</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="550"/>
        <source>&amp;New PlayList</source>
        <translation>新しいプレイリスト(&amp;N)</translation>
    </message>
</context>
<context>
    <name>PlayListBrowser</name>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="14"/>
        <source>Playlist Browser</source>
        <translation>プレイリストブラウザー</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="45"/>
        <source>New</source>
        <translation>新規</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="52"/>
        <location filename="../playlistbrowser.cpp" line="39"/>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="69"/>
        <location filename="../forms/playlistbrowser.ui" line="79"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../playlistbrowser.cpp" line="38"/>
        <source>Rename</source>
        <translation>名前を変更</translation>
    </message>
</context>
<context>
    <name>PlayListSelector</name>
    <message>
        <location filename="../playlistselector.cpp" line="51"/>
        <source>&amp;Load</source>
        <translation>読込(&amp;L)</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="52"/>
        <source>&amp;Save As...</source>
        <translation>名前を付けて保存(&amp;A)...</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="54"/>
        <source>Rename</source>
        <translation>名前を変更</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="55"/>
        <source>&amp;Delete</source>
        <translation>削除(&amp;D)</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="112"/>
        <source>Rename Playlist</source>
        <translation>プレイリスト名を変更</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="112"/>
        <source>Playlist name:</source>
        <translation>プレイリスト名:</translation>
    </message>
</context>
<context>
    <name>PopupSettings</name>
    <message>
        <location filename="../forms/popupsettings.ui" line="14"/>
        <source>Popup Information Settings</source>
        <translation>吹き出し情報の設定</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="29"/>
        <source>Template</source>
        <translation>ひな形</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="58"/>
        <source>Reset</source>
        <translation>リセット</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="65"/>
        <source>Insert</source>
        <translation>挿入</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="75"/>
        <source>Show cover</source>
        <translation>表紙を表示</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="89"/>
        <source>Cover size:</source>
        <translation>表紙の大きさ:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="115"/>
        <source>Transparency:</source>
        <translation>透明度:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="145"/>
        <source>Delay:</source>
        <translation>残映時間:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="178"/>
        <source>ms</source>
        <translation>ミリ秒</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="62"/>
        <source>Artist</source>
        <translation>アーティスト</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="63"/>
        <source>Album</source>
        <translation>アルバム</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="64"/>
        <source>Title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="65"/>
        <source>Track number</source>
        <translation>トラック番号</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="66"/>
        <source>Two-digit track number</source>
        <translation>トラック番号 数字2桁</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="67"/>
        <source>Genre</source>
        <translation>ジャンル</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="68"/>
        <source>Comment</source>
        <translation>コメント</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="69"/>
        <source>Composer</source>
        <translation>作曲者</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="70"/>
        <source>Duration</source>
        <translation>再生時間</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="71"/>
        <source>Disc number</source>
        <translation>ディスク番号</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="72"/>
        <source>File name</source>
        <translation>ファイル名</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="73"/>
        <source>File path</source>
        <translation>ファイルパス</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="74"/>
        <source>Year</source>
        <translation>年</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="75"/>
        <source>Condition</source>
        <translation>定番</translation>
    </message>
</context>
<context>
    <name>PresetEditor</name>
    <message>
        <location filename="../forms/preseteditor.ui" line="14"/>
        <source>Preset Editor</source>
        <translation>プリセットエディター</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="36"/>
        <source>Preset</source>
        <translation>プリセット</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="52"/>
        <source>Auto-preset</source>
        <translation>自動プリセット</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="77"/>
        <source>Load</source>
        <translation>読込</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="84"/>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="71"/>
        <source>Unknown command</source>
        <translation>不明なコマンドです</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="176"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>使用法: qmmp [オプション] [ファイル名:複数可]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="177"/>
        <source>Options:</source>
        <translation>オプション:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="181"/>
        <source>Don&apos;t start the application</source>
        <translation>アプリケーションを始動しない</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="182"/>
        <source>Display this text and exit</source>
        <translation>このメッセージを表示して終了</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="183"/>
        <source>Print version number and exit</source>
        <translation>バージョン番号を表示して終了</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="184"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>名案, パッチ, バグ報告は forkotov02@hotmail.ru まで</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="189"/>
        <source>QMMP version:</source>
        <translation>QMMP のバージョン:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="190"/>
        <source>Qt version:</source>
        <translation>Qt のバージョン:</translation>
    </message>
</context>
<context>
    <name>ShortcutDialog</name>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="14"/>
        <source>Change Shortcut</source>
        <translation>ショートカットを変更</translation>
    </message>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>割り当てたい組み合わせキーを押します</translation>
    </message>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="43"/>
        <source>Clear</source>
        <translation>消去</translation>
    </message>
</context>
<context>
    <name>TextScroller</name>
    <message>
        <location filename="../textscroller.cpp" line="53"/>
        <source>Autoscroll Songname</source>
        <translation>曲名を自動スクロール</translation>
    </message>
    <message>
        <location filename="../textscroller.cpp" line="118"/>
        <source>Buffering: %1%</source>
        <translation>バッファーへ先読み: %1%</translation>
    </message>
</context>
<context>
    <name>VisualMenu</name>
    <message>
        <location filename="../visualmenu.cpp" line="29"/>
        <source>Visualization</source>
        <translation>視覚効果</translation>
    </message>
</context>
</TS>
